==> rbac-server-1.1.9.3-Release-sources.jar: com/bizunited/platform/rbac/server/vo/OrganizationVo.java <==
package com.bizunited.platform.rbac.server.vo;

import java.util.Date;
import java.util.Set;

import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumnRelation;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumnRelation.RelationType;
import com.bizunited.platform.saturn.engine.annotation.SaturnDefaultController;
import com.bizunited.platform.saturn.engine.annotation.SaturnDefaultController.Type;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;

/**
 * 组织机构信息的Vo模型支持
 * @author yinwenjie
 */
@SaturnEntity(name="OrganizationVo" , description="组织机构")
public class OrganizationVo {
  /**
   * 抽象VO层模型的编号信息.
   */
  @SaturnColumn(pkColumn=true , insertable=true , updatable=false , nullable=true , description="主键")
  private String id;
  @SaturnColumn(description="组织机构的唯一编号" , length=128 , nullable=false,unique = true)
  private String code;
  @SaturnColumn(description = "组织机构名称", length = 64, nullable = false)
  private String orgName;
  @SaturnColumn(description = "组织机构类型", nullable = false)
  private Integer type;
  @SaturnColumn(description = "组织机构描述", nullable = false, length = 512)
  private String description = "";
  @SaturnColumn(description = "组织机构排序", nullable = false)
  private Integer sortIndex = 100;
  @SaturnColumn(description = "创建时间", nullable = false)
  private Date createTime = new Date();
  @SaturnColumn(description = "组织机构绑定的用户信息")
  @SaturnColumnRelation(type=RelationType.ManyToMany , master=true , mappedBy="orgs")
  private Set<UserVo> users;
  @SaturnColumn(description = "组织机构绑定的用户信息")
  @SaturnColumnRelation(type=RelationType.OneToMany , mappedBy="organization")
  private Set<PositionVo> positions;
  @SaturnColumn(description = "组织机构状态", nullable = false)
  @SaturnDefaultController(defaultType=Type.SELECT , defaultKeys="正常,不正常" , defaultValues="1,0")
  private Integer tstatus;
  public String getId() {
    return id;
  }
  public void setId(String id) {
    this.id = id;
  }
  public String getCode() {
    return code;
  }
  public void setCode(String code) {
    this.code = code;
  }
  public String getOrgName() {
    return orgName;
  }
  public void setOrgName(String orgName) {
    this.orgName = orgName;
  }
  public Integer getType() {
    return type;
  }
  public void setType(Integer type) {
    this.type = type;
  }
  public String getDescription() {
    return description;
  }
  public void setDescription(String description) {
    this.description = description;
  }
  public Integer getSortIndex() {
    return sortIndex;
  }
  public void setSortIndex(Integer sortIndex) {
    this.sortIndex = sortIndex;
  }
  public Date getCreateTime() {
    return createTime;
  }
  public void setCreateTime(Date createTime) {
    this.createTime = createTime;
  }
  public Set<UserVo> getUsers() {
    return users;
  }
  public void setUsers(Set<UserVo> users) {
    this.users = users;
  }
  public Set<PositionVo> getPositions() {
    return positions;
  }
  public void setPositions(Set<PositionVo> positions) {
    this.positions = positions;
  }
  public Integer getTstatus() {
    return tstatus;
  }
  public void setTstatus(Integer tstatus) {
    this.tstatus = tstatus;
  }
}

==> rbac-server-1.2.2-Release-sources.jar: com/bizunited/platform/rbac/server/vo/OrganizationVo.java <==
package com.bizunited.platform.rbac.server.vo;

import java.util.Date;
import java.util.Set;

import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumnRelation;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumnRelation.RelationType;
import com.bizunited.platform.saturn.engine.annotation.SaturnDefaultController;
import com.bizunited.platform.saturn.engine.annotation.SaturnDefaultController.Type;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;

/**
 * 组织机构信息的Vo模型支持
 * @author yinwenjie
 */
@SaturnEntity(name="OrganizationVo" , description="组织机构")
public class OrganizationVo {
  /**
   * 抽象VO层模型的编号信息.
   */
  @SaturnColumn(pkColumn=true , insertable=true , updatable=false , nullable=true , description="主键")
  private String id;
  @SaturnColumn(description="组织机构的唯一编号" , length=128 , nullable=false,unique = true)
  private String code;
  @SaturnColumn(description = "组织机构名称", length = 64, nullable = false)
  private String orgName;
  @SaturnColumn(description = "组织机构类型", nullable = false)
  private Integer type;
  @SaturnColumn(description = "组织机构描述", nullable = false, length = 512)
  private String description = "";
  @SaturnColumn(description = "组织机构排序", nullable = false)
  private Integer sortIndex = 100;
  @SaturnColumn(description = "创建时间", nullable = false)
  private Date createTime = new Date();
  @SaturnColumn(description = "组织机构绑定的用户信息")
  @SaturnColumnRelation(type=RelationType.ManyToMany , master=true , mappedBy="orgs")
  private Set<UserVo> users;
  @SaturnColumn(description = "组织机构绑定的角色信息")
  @SaturnColumnRelation(type=RelationType.ManyToMany , master=true , mappedBy="orgs")
  private Set<RoleVo> roles;
  @SaturnColumn(description = "组织机构绑定的岗位信息")
  @SaturnColumnRelation(type=RelationType.OneToMany , mappedBy="organization")
  private Set<PositionVo> positions;
  @SaturnColumn(description = "父级组织")
  @SaturnColumnRelation(type=RelationType.ManyToOne)
  OrganizationVo parent;
  @SaturnColumn(description = "组织机构状态", nullable = false)
  @SaturnDefaultController(defaultType=Type.SELECT , defaultKeys="正常,不正常" , defaultValues="1,0")
  private Integer tstatus;
  public String getId() {
    return id;
  }
  public void setId(String id) {
    this.id = id;
  }
  public String getCode() {
    return code;
  }
  public void setCode(String code) {
    this.code = code;
  }
  public String getOrgName() {
    return orgName;
  }
  public void setOrgName(String orgName) {
    this.orgName = orgName;
  }
  public Integer getType() {
    return type;
  }
  public void setType(Integer type) {
    this.type = type;
  }
  public String getDescription() {
    return description;
  }
  public void setDescription(String description) {
    this.description = description;
  }
  public Integer getSortIndex() {
    return sortIndex;
  }
  public void setSortIndex(Integer sortIndex) {
    this.sortIndex = sortIndex;
  }
  public Date getCreateTime() {
    return createTime;
  }
  public void setCreateTime(Date createTime) {
    this.createTime = createTime;
  }
  public Set<UserVo> getUsers() {
    return users;
  }
  public void setUsers(Set<UserVo> users) {
    this.users = users;
  }
  public Set<RoleVo> getRoles() {
    return roles;
  }
  public void setRoles(Set<RoleVo> roles) {
    this.roles = roles;
  }
  public Set<PositionVo> getPositions() {
    return positions;
  }
  public void setPositions(Set<PositionVo> positions) {
    this.positions = positions;
  }
  public OrganizationVo getParent() {
    return parent;
  }
  public void setParent(OrganizationVo parent) {
    this.parent = parent;
  }
  public Integer getTstatus() {
    return tstatus;
  }
  public void setTstatus(Integer tstatus) {
    this.tstatus = tstatus;
  }
}
